# square_file_store

## about

file storage layer for my personal server.

## installation

```shell
pip install square_file_store
```

## configs

1. square_file_store\data\config.ini

## env

- python>=3.12.0

## changelog

### v1.0.1

- replace file_purpose with app_id.

### v1.0.0

- initial implementation.

## Feedback is appreciated. Thank you!